import re

def neighbors(router, routing_instances=["IAS"], group_expression=None):

    for config in router["bgp"]["configuration"]:
        for ri in config["routing-instances"]:
            for inst in ri["instance"]:
                if inst["name"]["data"] not in routing_instances:
                    continue
                for prot in inst["protocols"]:
                    for bgp in prot.get("bgp", []):
                        for g in bgp.get("group", []):
                            if group_expression and not \
                                    re.match(group_expression, g["name"]["data"]):
                                continue
                            for n in g["neighbor"]:
                                yield n


def interfaces(router):
    for ifc_info in router["interfaces"]["interface-information"]:
        for ifc_list in ifc_info["logical-interface"]:
            for ifc in ifc_list:
                yield {
                    "name": ifc["name"][0]["data"],
                    "status": "%s/%s" % (
                        ifc["admin-status"][0]["data"],
                        ifc["oper-status"][0]["data"]),
                    "description": ifc["description"][0]["data"],
                    "type": "logical"
                }